==> rascore-0.1.34-py3-none-any.whl: rascore/util/functions/file.py <==
# -*- coding: utf-8 -*-
"""
MIT License

Copyright (c) 2022 Mitchell Isaac Parker

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

pdbaa_fasta_file = "pdbaa.fasta"

entry_table_file = "entry.txt"

coord_table_file = "coord.txt"
sifts_json_file = "sifts.json"

lig_table_file = "ligand.txt"
prot_table_file = "protein.txt"
mut_table_file = "mutation.txt"
cf_table_file = "cf.txt"

edia_json_file = "edia.json"
map_json_file = "map.json"
dih_json_file = "dihedral.json"
interf_json_file = "interface.json"
pocket_json_file = "pocket.json"

dih_table_file = "dihedral.txt"
edia_table_file = "edia.txt"
dist_table_file = "distance.txt"
interf_table_file = "interface.txt"
pocket_table_file = "pocket.txt"

fit_table_file = "fit.txt"
pred_table_file = "predict.txt"

dih_matrix_file = "dihedral.csv"
dist_matrix_file = "distance.csv"
rmsd_matrix_file = "rmsd.csv"
interf_matrix_file = "interface.csv"
pocket_matrix_file = "pocket.csv"

max_norm_file = "max_norm.csv"
mean_norm_file = "mean_norm.csv"
max_flip_file = "max_flip.csv"
mean_flip_file = "mean_flip.csv"

rmsd_json_file = "rmsd.json"

fit_matrix_file = "fit.csv"
pred_matrix_file = "pred.csv"

dih_fit_matrix_file = "dihedral_fit.csv"
dih_pred_matrix_file = "dihedral_pred.csv"
rmsd_fit_matrix_file = "rmsd_fit.csv"
rmsd_pred_matrix_file = "rmsd_pred.csv"
dist_fit_matrix_file = "dist_fit.csv"
dist_pred_matrix_file = "pred_fit.csv"

cluster_table_file = "cluster.txt"
result_table_file = "result.txt"
cluster_report_table_file = "cluster_report.txt"
classify_report_table_file = "classify_report.txt"
sum_table_file = "summary.txt"
cutoff_table_file = "cutoff.txt"
count_table_file = "count.txt"

plot_img_file = "plot.pdf"
legend_img_file = "legend.pdf"
venn_img_file = "venn.pdf"

pymol_pml_file = "pymol.pml"

stat_table_file = "statistic.txt"

nom_table_file = "nomenclature.txt"

==> rascore-0.2.0-py3-none-any.whl: rascore/util/functions/file.py <==
# -*- coding: utf-8 -*-
"""
MIT License

Copyright (c) 2022 Mitchell Isaac Parker

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

pdbaa_fasta_file = "pdbaa.fasta"

entry_table_file = "entry.tsv"

coord_table_file = "coord.tsv"
sifts_json_file = "sifts.json"

lig_table_file = "ligand.tsv"
prot_table_file = "protein.tsv"
mut_table_file = "mutation.tsv"
cf_table_file = "cf.tsv"

edia_json_file = "edia.json"
map_json_file = "map.json"
dih_json_file = "dihedral.json"
interf_json_file = "interface.json"
pocket_json_file = "pocket.json"

dih_table_file = "dihedral.tsv"
edia_table_file = "edia.tsv"
dist_table_file = "distance.tsv"
interf_table_file = "interface.tsv"
pocket_table_file = "pocket.tsv"

fit_table_file = "fit.tsv"
pred_table_file = "predict.tsv"

dih_matrix_file = "dihedral.csv"
dist_matrix_file = "distance.csv"
rmsd_matrix_file = "rmsd.csv"
interf_matrix_file = "interface.csv"
pocket_matrix_file = "pocket.csv"

max_norm_file = "max_norm.csv"
mean_norm_file = "mean_norm.csv"
max_flip_file = "max_flip.csv"
mean_flip_file = "mean_flip.csv"

rmsd_json_file = "rmsd.json"

fit_matrix_file = "fit.csv"
pred_matrix_file = "pred.csv"

dih_fit_matrix_file = "dihedral_fit.csv"
dih_pred_matrix_file = "dihedral_pred.csv"
rmsd_fit_matrix_file = "rmsd_fit.csv"
rmsd_pred_matrix_file = "rmsd_pred.csv"
dist_fit_matrix_file = "dist_fit.csv"
dist_pred_matrix_file = "pred_fit.csv"

cluster_table_file = "cluster.tsv"
result_table_file = "result.tsv"
cluster_report_table_file = "cluster_report.tsv"
classify_report_table_file = "classify_report.tsv"
sum_table_file = "summary.tsv"
cutoff_table_file = "cutoff.tsv"
count_table_file = "count.tsv"

plot_img_file = "plot.pdf"
legend_img_file = "legend.pdf"
venn_img_file = "venn.pdf"

pymol_pml_file = "pymol.pml"

stat_table_file = "statistic.tsv"

nom_table_file = "nomenclature.tsv"
